#
# spec file for package memprof
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           memprof
Version:        0.6.2
Release:        24.1
Summary:        A Memory Profiler with GNOME Interface
License:        GPL-2.0-or-later
Group:          Development/Tools/Debuggers
URL:            http://www.gnome.org/projects/memprof/
Source:         https://download.gnome.org/sources/memprof/0.6/%{name}-%{version}.tar.bz2
# PATCH-FIX-UPSTREAM memprof-bfd-headers.patch bgo#688398 dmistar@opensuse.org -- Fix new binutils requirement to include config.h
Patch2:         memprof-bfd-headers.patch
# PATCH-MISSING-TAG -- See http://en.opensuse.org/Packaging/Patches
Patch3:         memprof-0.5.1-desktop.patch
# PATCH-FIX-UPSTREAM memprof-arch-neutral.patch bgo#663253 rcoe@wi.rr.com -- Fix build on different archs than x86_64 and i586.
Patch4:         memprof-arch-neutral.patch
BuildRequires:  binutils-devel
BuildRequires:  fdupes
BuildRequires:  gtk2-devel
BuildRequires:  intltool
BuildRequires:  libglade2-devel
BuildRequires:  pkg-config
BuildRequires:  update-desktop-files
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# Depend on x86 instruction set.
ExclusiveArch:  %ix86 x86_64

%description
With this application, profile applications for their memory
requirements and hunt for leaks very easily.

%lang_package

%prep
%setup -q
%patch -P 3
%patch -P 4 -p1
%patch -P 2 -p1

%build
export CFLAGS="%{optflags} -fno-strict-aliasing" CXXFLAGS="%{optflags} -fno-strict-aliasing"
%configure \
  --disable-static
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
find %{buildroot} -type f -name "*.la" -delete -print
# Change sr@Latn to sr@latin
mv %{buildroot}%{_datadir}/locale/sr@Latn %{buildroot}%{_datadir}/locale/sr@latin
%find_lang memprof %{?no_lang_C}
%suse_update_desktop_file %{name} Development Profiling
%fdupes %{buildroot}

%post
/sbin/ldconfig
%if 0%{?suse_version} > 1130
%desktop_database_post
%endif

%postun
/sbin/ldconfig
%if 0%{?suse_version} > 1130
%desktop_database_postun
%endif

%files
%defattr(-, root, root)
%doc AUTHORS COPYING ChangeLog NEWS README
%{_bindir}/*
%dir %{_libdir}/memprof
%{_libdir}/memprof/*.so
%{_datadir}/memprof/
%{_datadir}/pixmaps/*
%{_datadir}/applications/memprof.desktop

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Thu Feb  8 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Prepare for RPM 4.20: patchN -> patch -P N.
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Thu Jan 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Mon Sep 21 2015 mpluskal@suse.com
- Use url for source
- Cleanup spec file with spec-cleaner
* Thu Nov 15 2012 dimstar@opensuse.org
- Add memprof-bfd-headers.patch: binutils newly forces the
  inclusion of config.h.
* Mon Jul 30 2012 dvaleev@suse.com
- As memprof uses x86 instruction sets, add exclusive arch for
  x86 types (%%{ix86} x86_64).
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sun Oct 30 2011 rcoe@wi.rr.com
- Add memprof-arch-neutral.patch: Fix build error making
  stack-frame.h arch neutral based on word size and not arch name.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Mon Aug  9 2010 vuntz@opensuse.org
- Update to version 0.6.2:
  + Do not open /proc/self/perfctr with O_CREAT.
  + Provide a GtkFileChooseButton to select the executable.
  + Add a detail window.
  + Cleanup code to avoid #ifdef depending on the arch.
  + Fix crashes.
- Changes from version 0.6.1:
  + Port to Goption.
  + Improve default window size.
  + Add support to save the memory profile to a file.
  + Remove follow-fork/follow-exec/preferences menu items.
  + Use some code from sysprof.
  + UI tweaks.
  + Code cleanups and build fixes.
  + Remove dependencies on gconf, libbfd, libiberty, libgnome,
    libgnomecanvas, libgnomeui, popt.
  + Updated translations.
- Remove libgnomeui-devel, perl-XML-Parser BuildRequires.
- Add explicit gtk2-devel BuildRequires.
- Drop memprof.diff: fixed upstream.
- Drop memprof-0.5.1-protos.patch: it doesn't apply anymore, and it
  looks like it could be fixed.
- Drop memprof-build-error.patch: fixed upstream.
- Drop memprof-0.6-nonx86.patch: it doesn't apply anymore, and it
  looks like it could be fixed.
- Drop memprof-0.6-bfd.patch: not needed anymore.
- Do not call %%suse_update_config, intltoolize and autoreconf.
- Remove gconf schema handling, since there's no gconf schema
  anymore.
- Use %%configure and %%makeinstall macros.
- Remove .la files.
* Mon Feb 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Sat Jan 31 2009 vuntz@novell.com
- Use sr@latin instead of sr@Latn.
* Mon Jul 14 2008 schwab@suse.de
- Fix check for libbfd.
* Tue Jan 22 2008 aj@suse.de
- Fix open call.
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage
- s#%%run_ldconfig#/sbin/ldconfig/ in %%post and %%postun.
* Wed Mar 28 2007 maw@suse.de
- Add the magic gconf schemas stuff.
* Mon Jan 22 2007 aj@suse.de
- Move to /usr.
- Cleanup BuildRequires.
* Thu Jan 11 2007 schwab@suse.de
- Add binutils-devel to BuildRequires.
* Sun Oct 15 2006 ro@suse.de
- try to fix build for non-x86
* Fri Oct 13 2006 danw@suse.de
- Remove dead patch
* Mon Sep 25 2006 jhargadon@suse.de
- update to version 0.6
- Rewritten profiling module that handles recursion better
- Display the call tree of functions
- Many bug fixes
- New and updated translations
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Nov  3 2004 ro@suse.de
- locale rename: no -> nb
* Wed Aug  4 2004 ro@suse.de
- make it build with current binutils
- recode desktop file to utf-8
* Fri Jul  9 2004 uli@suse.de
- fixed to build on non-x86 systems
* Wed May 12 2004 clahey@suse.de
- Disable gconf makefile install rule.
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Dec 19 2003 pthomas@suse.de
- Refresh configury via autoreconf.
- Require intltool and run intltoolize.
- Disable building the unneeded static version of libmemintercept
  and explicitly package the dynamic one.
- Call find_lang in specfile.
* Sat Aug 16 2003 adrian@suse.de
- update to version 0.5.1 (Gnome 2 based)
- hopefully correct fixed for non-ix86
- add Categories
* Fri Sep 27 2002 ro@suse.de
- Added alsa alsa-devel to neededforbuild (esound)
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuild
* Fri May 31 2002 ro@suse.de
- fix build on lib64 platforms
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Wed Mar 14 2001 ro@suse.de
- added xf86 to neededforbuild
* Tue Mar  6 2001 egger@suse.de
- Initial SuSE version.
